@@ -1,4 +1,4 @@
-# Copyright (c) 2021 CRS4
+# Copyright (c) 2019-2022 CRS4
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -115,7 +115,7 @@ def main(args):
         ecvl.ColorType.none,
         1,
         args.queue_ratio,
-        [True, False]
+        {"training": False, "test": False}
     )
     for nw in 1, 2, 8:
         print(f"Running with {nw} workers")
